@@ -10,7 +10,7 @@ use MIME::Base64;
 use XML::Parser;
 
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 our @EXPORT = qw<
     decode_xmlrpc encode_xmlrpc
@@ -59,8 +59,8 @@ sub encode_xmlrpc {
     $xml .= "<methodName>$method</methodName>" if $type eq "method";
 
     if ($type eq "fault") {
-        $args[0] //= "";
-        $args[1] //= "";
+        $args[0] = "" unless defined $args[0];
+        $args[1] = "" unless defined $args[1];
 
         $xml .= "<fault><value><struct><member><name>faultCode</name>"
               . "<value><int>$args[0]</int></value></member>"
@@ -718,6 +718,12 @@ See L<http://www.xmlrpc.com/> for more information about the XML-RPC
 specification.
 
 
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+
 =head1 AUTHOR
 
 SE<eacute>bastien Aperghis-Tramoni E<lt>saper@cpan.orgE<gt>
